@@ -1,6 +1,6 @@
 from enum import Enum
 
-class HttpMethod(Enum):
+class HttpMethod(str, Enum):
     GET = 'GET'
     POST = 'POST'
     PATCH = 'PATCH'
\ No newline at end of file
